/*
 *    Copyright (c) 2018-2025, hnqz All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the pig4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: hnqz
 */

import request from '@/router/axios'

// 分页查询
export function getPageTasklist(query) {
  return request({
    url: '/admin/wmscorepackage/getWmScorePageTask',
    method: 'get',
    params: query
  })
}

// 查看的分页查询
export function fetchSubList(query) {
  return request({
    url: '/admin/wmtask/pageSum',
    method: 'get',
    params: query
  })
}

// 导出汇总报告
export function taskExportNbqybg(query) {
  return request({
    url: '/admin/wmtask/exportNba',
    method: 'get',
    params: query
  })
}
// 导出汇总报告
export function taskExportExcelNbqybg(query) {
  return request({
    url: '/admin/report/excel/export/exportNba',
    method: 'get',
    params: query
  })
}

// 导出报告详情
export function taskExportNbqybgInfo(query) {
  return request({
    url: '/admin/export/exportNbInfo',
    method: 'get',
    params: query
  })
}

// 生成报告-展示
export function selectScore(query) {
  return request({
    url: '/admin/wmtask/selectReport',
    method: 'get',
    params: query
  })
}
// 生成报告并审批
export function saveAndUpdateWmReport(query) {
  return request({
    url: '/admin/wmtask/saveAndUpdateWmReport',
    method: 'get',
    params: query
  })
}

// 生成报告-提交
export function saveAndUpdateWmTask(query) {
  return request({
    url: '/admin/wmtask/saveAndUpdateWmTask',
    method: 'get',
    params: query
  })
}



// 导出新版汇总报告
export function taskNewExportNbqybg(query) {
  return request({
    url: '/admin/reportExport/new-nba-export',
    method: 'get',
    params: query
  })
}


// 导出汇总报告
export function taskExportNewExcelNbqybg(query) {
  return request({
    url: '/admin/reportExport/new-excel-export',
    method: 'get',
    params: query
  })
}

